Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(341)

Unified Diff: webrtc/p2p/base/transportchannelimpl.h

Issue 1996693002: Fire a signal when the transport channel state changes (Closed) Base URL: https://chromium.googlesource.com/external/webrtc@master
Patch Set: Changed signal name to SignalStateChanged Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « webrtc/p2p/base/port.cc ('k') | webrtc/p2p/base/transportcontroller.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webrtc/p2p/base/transportchannelimpl.h
diff --git a/webrtc/p2p/base/transportchannelimpl.h b/webrtc/p2p/base/transportchannelimpl.h
index f548aa012f80a3463ecf737ef55d4bffd7d14b0d..70cb4e292f615fbba1d91316139c1649a6d9574f 100644
--- a/webrtc/p2p/base/transportchannelimpl.h
+++ b/webrtc/p2p/base/transportchannelimpl.h
@@ -100,9 +100,8 @@ class TransportChannelImpl : public TransportChannel {
// agents.
sigslot::signal1<TransportChannelImpl*> SignalRoleConflict;
- // Emitted whenever the number of connections available to the transport
- // channel decreases.
- sigslot::signal1<TransportChannelImpl*> SignalConnectionRemoved;
+ // Emitted whenever the transport channel state changed.
+ sigslot::signal1<TransportChannelImpl*> SignalStateChanged;
private:
RTC_DISALLOW_COPY_AND_ASSIGN(TransportChannelImpl);
« no previous file with comments | « webrtc/p2p/base/port.cc ('k') | webrtc/p2p/base/transportcontroller.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698